var
	y $y$, 
	x $x$, 
	g $g$, 
	r $r$, 
	pi $\pi$, 
	a $a$, 
	e $e$, 
	z $z$ ;

varexo 
	eps_r $\varepsilon^r$, 
	eps_a $\varepsilon^z$, 
	eps_e $\varepsilon^e$, 
	eps_z $\varepsilon^z$ ;

parameters 
	beta $\beta$, 
	omega $\omega$, 
	psi $\psi$,
	rho_pi $\rho_\pi$, 
	rho_g $\rho_g$,
	rho_x $\rho_x$,
	rho_a $\rho_a$,
	rho_e $\rho_e$,
	sig_r $\sigma_r$,
	sig_z $\sigma_z$,
	sig_a $\sigma_a$,
	sig_e $\sigma_e$ ;

beta   = 0.99 ;
psi    = 0.1 ;
omega  = 0.0617;

model (linear) ;
	x  = x(+1) - ( r - pi(+1) ) + ( 1 - omega ) * ( 1 - rho_a ) * a ;
        pi = beta * pi(+1) + psi * x - e ;
        r  = r(-1) + rho_pi * pi + rho_g * g + rho_x * x + eps_r ;
        x  = y - omega * a ;
        g  = y - y(-1) + z ;
        a  = rho_a * a(-1) + eps_a ;
        e  = rho_e * e(-1) + eps_e ;
        z  = eps_z ;
end ;

//steady;

shocks ;
	var eps_a = sig_a^2 ;
	var eps_e = sig_e^2 ;
	var eps_z = sig_z^2 ;
	var eps_r = sig_r^2 ;
end ;

estimated_params;
	rho_a, 0.9 ;
	rho_e, 0.9 ;
	rho_pi, 0.4 ;
	rho_g, 0.3 ;
	rho_x, 0.05 ;
	stderr eps_a, 0.1 ;
	stderr eps_e, 0.1 ;
	stderr eps_z, 0.1 ;
	stderr eps_r, 0.1 ;
end;

varobs pi r g;

estimation(datafile=data, tex);
//estimation(datafile=data, tex, mh_jscale=0.55, mh_replic=2000, mh_nblocks=1, mh_drop=0.2, mode_check);

write_latex_dynamic_model ;